# Changelog

All notable changes to this project will be documented in this file.

The format is based on Keep a Changelog (https://keepachangelog.com/en/1.0.0/),
and this project adheres to Semantic Versioning (https://semver.org/spec/v2.0.0.html).

## [0.1.0] - 2025-11-16

### Added

- Initial pico-celery integration library for Pico-IoC and Celery.
- Async task decorator for component methods.
- Celery app factory based on Pico-IoC configuration.
- Automatic task discovery and registration through the Pico-IoC container.
- Basic tests and documentation.
